@@ -22,12 +22,12 @@ public:
 
     void sort(int column, Qt::SortOrder order = Qt::AscendingOrder) override;
 
-    Q_REQUIRED_RESULT const QStringList &categories() const
+    [[nodiscard]] const QStringList &categories() const
     {
         return mCategories;
     }
 
-    Q_REQUIRED_RESULT const QStringList &priorities() const
+    [[nodiscard]] const QStringList &priorities() const
     {
         return mPriorities;
     }
@@ -43,6 +43,7 @@ public Q_SLOTS:
 private:
     int compareStartDates(const QModelIndex &left, const QModelIndex &right) const;
     int compareDueDates(const QModelIndex &left, const QModelIndex &right) const;
+    int compareCompletedDates(const QModelIndex &left, const QModelIndex &right) const;
     int comparePriorities(const QModelIndex &left, const QModelIndex &right) const;
     int compareCompletion(const QModelIndex &left, const QModelIndex &right) const;
     QStringList mCategories;
@@ -50,4 +51,3 @@ private:
     Qt::SortOrder mSortOrder = Qt::AscendingOrder;
     EventViews::PrefsPtr mPreferences;
 };
-
